Coverage report

File | function | statements | missing | excluded | coverage
--- | --- | --- | --- | --- | ---
ezdag/dags.py | DAG.__init__ | 11 | 1 | 0 | 90.9%
ezdag/dags.py | DAG.attach | 30 | 5 | 0 | 83.3%
ezdag/dags.py | DAG.create_log_dir | 2 | 2 | 0 | 0.0%
ezdag/dags.py | DAG.write | 7 | 1 | 0 | 85.7%
ezdag/dags.py | DAG.submit | 8 | 8 | 0 | 0.0%
ezdag/dags.py | DAG.write_dag | 4 | 4 | 0 | 0.0%
ezdag/dags.py | DAG.write_script | 4 | 4 | 0 | 0.0%
ezdag/dags.py | DAG._write_dag | 10 | 2 | 0 | 80.0%
ezdag/dags.py | DAG._write_script | 11 | 1 | 0 | 90.9%
ezdag/dags.py | DAG._get_edge_type | 8 | 1 | 0 | 87.5%
ezdag/dags.py | EdgeConnector.__init__ | 1 | 0 | 0 | 100.0%
ezdag/dags.py | EdgeConnector.get_edges | 2 | 0 | 0 | 100.0%
ezdag/dags.py | write_dag | 6 | 6 | 0 | 0.0%
ezdag/dags.py | (no function) | 27 | 0 | 0 | 100.0%
ezdag/format.py | _separated_factory | 2 | 0 | 0 | 100.0%
ezdag/format.py | _separated_factory._joiner | 1 | 0 | 0 | 100.0%
ezdag/format.py | _format_argument | 1 | 1 | 0 | 0.0%
ezdag/format.py | _format_arguments | 1 | 1 | 0 | 0.0%
ezdag/format.py | _format_environment | 1 | 0 | 0 | 100.0%
ezdag/format.py | _format_classad_item | 1 | 0 | 0 | 100.0%
ezdag/format.py | _format_classad_boolean_expression | 1 | 0 | 0 | 100.0%
ezdag/format.py | _semicolon_separated_pairs | 2 | 0 | 0 | 100.0%
ezdag/format.py | _semicolon_separated_pairs._format_item | 4 | 1 | 0 | 75.0%
ezdag/format.py | _format_condor_command_value | 7 | 1 | 0 | 85.7%
ezdag/format.py | format_submit_description | 4 | 0 | 0 | 100.0%
ezdag/format.py | (no function) | 16 | 0 | 0 | 100.0%
ezdag/layers.py | Layer.__post_init__ | 6 | 0 | 0 | 100.0%
ezdag/layers.py | Layer.config | 5 | 1 | 0 | 80.0%
ezdag/layers.py | Layer.append | 7 | 0 | 0 | 100.0%
ezdag/layers.py | Layer.extend | 2 | 1 | 0 | 50.0%
ezdag/layers.py | Layer.__iadd__ | 4 | 1 | 0 | 75.0%
ezdag/layers.py | Layer.new | 1 | 1 | 0 | 0.0%
ezdag/layers.py | Layer.validate | 17 | 3 | 0 | 82.4%
ezdag/layers.py | Layer.command | 10 | 1 | 0 | 90.0%
ezdag/layers.py | Layer.has_dependencies | 1 | 0 | 0 | 100.0%
ezdag/layers.py | Layer._arguments | 14 | 2 | 0 | 85.7%
ezdag/layers.py | Layer._inputs | 6 | 1 | 0 | 83.3%
ezdag/layers.py | Layer._outputs | 6 | 1 | 0 | 83.3%
ezdag/layers.py | Layer._output_remaps | 6 | 1 | 0 | 83.3%
ezdag/layers.py | Layer._vars | 23 | 0 | 0 | 100.0%
ezdag/layers.py | Layer._update_submit_defaults | 26 | 3 | 0 | 88.5%
ezdag/layers.py | Node.__post_init__ | 9 | 0 | 0 | 100.0%
ezdag/layers.py | Node.requires | 2 | 0 | 0 | 100.0%
ezdag/layers.py | Node.provides | 2 | 0 | 0 | 100.0%
ezdag/layers.py | HexFormatter.__init__ | 3 | 0 | 0 | 100.0%
ezdag/layers.py | HexFormatter.parse | 3 | 0 | 0 | 100.0%
ezdag/layers.py | _wrap_string_literal | 3 | 0 | 0 | 100.0%
ezdag/layers.py | (no function) | 60 | 0 | 0 | 100.0%
ezdag/options.py | Argument.__post_init__ | 6 | 0 | 0 | 100.0%
ezdag/options.py | Argument.args | 1 | 0 | 0 | 100.0%
ezdag/options.py | Argument.vars | 4 | 0 | 0 | 100.0%
ezdag/options.py | Argument.files | 4 | 0 | 0 | 100.0%
ezdag/options.py | Argument.remaps | 5 | 0 | 0 | 100.0%
ezdag/options.py | Option.__post_init__ | 7 | 0 | 0 | 100.0%
ezdag/options.py | Option.args | 1 | 0 | 0 | 100.0%
ezdag/options.py | Option.vars | 7 | 0 | 0 | 100.0%
ezdag/options.py | Option.files | 4 | 0 | 0 | 100.0%
ezdag/options.py | Option.remaps | 5 | 0 | 0 | 100.0%
ezdag/options.py | Literal.name | 1 | 0 | 0 | 100.0%
ezdag/options.py | Literal.args | 1 | 1 | 0 | 0.0%
ezdag/options.py | Literal.vars | 1 | 0 | 0 | 100.0%
ezdag/options.py | Literal.files | 1 | 0 | 0 | 100.0%
ezdag/options.py | Literal.remaps | 4 | 0 | 0 | 100.0%
ezdag/options.py | (no function) | 44 | 0 | 0 | 100.0%
ezdag/path.py | is_abs_or_url | 3 | 0 | 0 | 100.0%
ezdag/path.py | normalize | 3 | 0 | 0 | 100.0%
ezdag/path.py | (no function) | 5 | 0 | 0 | 100.0%
Total |  | 495 | 56 | 0 | 88.7%

No items found using the specified filter.